//-----------------------------LICENSE NOTICE------------------------------------
//  This file is part of Jarlac
//  Copyright (C) 2018 Retrobytes Productions
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//------------------------------------------------------------------------------

#include "enemies.h"


u8 fire(i16 xPos, i16 yPos, u8 enemyType, u8 facingLeft){

	return addEntity(enemyType, xPos + (facingLeft ? -3 : 3), yPos, facingLeft, globalEnemies);

}

void leftToRight(Entity* enemy, u8 bounce){

	u8 wall = onWall(enemy, FALSE);

	if(enemy->type <= ENEMY_TYPE_ESQUELETO && (wall || nextToHole(enemy))){ //Excepción Esqueleto torreta

		if((room != 26 || (enemy->yPos > 5 * 16 || enemy->facingLeft == FALSE)) && room != 57) enemy->facingLeft = !enemy->facingLeft;

	} 
	else{

		if(enemy->facingLeft){

			if(!wall && enemy->xPos > MIN_X){

				enemy->xPos -= enemy->xSpeed;

			}
			else{

				if(bounce)	enemy->facingLeft = FALSE;
				else{

					enemy->state = ENEMY_STATE_EXPLOSION;
					if(wall) cpct_akp_SFXPlay(FX_GOLPE, 15, 45, 0, 0, AY_CHANNEL_B);
				} 
			}

		}
		else{

			if(!wall && enemy->xPos < MAX_X - enemy->width){

				enemy->xPos += enemy->xSpeed;

			}
			else {

				if(bounce) enemy->facingLeft = TRUE;
				else{

					enemy->state = ENEMY_STATE_EXPLOSION;
					if(wall) cpct_akp_SFXPlay(FX_GOLPE, 15, 45, 0, 0, AY_CHANNEL_B);

				} 

			}

		}

	}
}


void voladorIA(Entity* enemy, Entity* hero){

	if(enemy->yPos > hero->yPos) enemy->yPos -= enemy->ySpeed;
	else if(enemy->yPos < hero->yPos) enemy->yPos += enemy->ySpeed;

	if(enemy->xPos > hero->xPos){  
	
		enemy->xPos -= enemy->xSpeed;
		enemy->facingLeft = TRUE;
	
	}
	else if(enemy->xPos < hero->xPos){

		enemy->xPos += enemy->xSpeed;
		enemy->facingLeft = FALSE;
	
	}
}

void esqueletoFire(Entity* enemy){

	
	u8 facingLeft = enemy->facingLeft;

	if(enemy->bullet == ENEMY_NO_BULLET || globalEnemies[enemy->bullet].state == ENEMY_STATE_INACTIVE){

		setAnimation(enemy, A_esqueletoAtack);
		if(enemy->finishedAnimation){

			enemy->bullet = fire(enemy->xPos + (facingLeft ? 0:2), enemy->yPos + 8, ENEMY_TYPE_BULLET, facingLeft);
			setAnimation(enemy, A_esqueletoWait);

		} 

	}
	else setAnimation(enemy, A_esqueletoWait);

}

void esqueletoIA(Entity* enemy, Entity* hero){

	u8 wall;

	u8 sameY = hero->yPos + HERO_H == enemy->yPos + ESQUELETO_H;

	if(sameY){

		if((hero->xPos < enemy->xPos && enemy->facingLeft) || (hero->xPos > enemy->xPos && !enemy->facingLeft)){

			enemy->alert = TRUE;
		}

	}

	if(enemy->alert){

		if(hero->xPos + HERO_W - 2 < enemy->xPos){

			enemy->facingLeft = TRUE;

			wall = onWall(enemy, FALSE) || nextToHole(enemy);

			if(!wall){

				enemy->xPos -= enemy->xSpeed + 1;
				setAnimation(enemy, A_esqueletoWalk);
			}
			else{

				esqueletoFire(enemy);
			}

		}
		else if(hero->xPos > enemy->xPos + ESQUELETO_W - 2){

			enemy->facingLeft = FALSE;

			wall = onWall(enemy, FALSE) || nextToHole(enemy);

			if(!wall){

				enemy->xPos += enemy->xSpeed + 1;
				setAnimation(enemy, A_esqueletoWalk);

			}
			else{

				esqueletoFire(enemy);

			}

		}
		else if(sameY){

			enemy->state = ENEMY_STATE_ATTACK;
			setAnimation(enemy, A_esqueletoAtack);

		}
		else{

			setAnimation(enemy, A_esqueletoWait);

		}


	}
	else{

		leftToRight(enemy, TRUE);

	}

}

void magoIA(Entity* enemy, Entity* hero){

	static u8 counter;

	Entity *brazo = &globalEnemies[2];

	if(++counter >= 35){

		if(enemy->facingLeft && hero->xPos > (6 * 8)){

			enemy->xPos = 9;
			enemy->facingLeft = FALSE;
			brazo->xPos = 9 + MAGO_W;
			brazo->facingLeft = FALSE;

		}
		else if(!enemy->facingLeft && hero->xPos < (4*8)){

			enemy->xPos = 7 * 9;
			enemy->facingLeft = TRUE;
			brazo->xPos = 7 * 9 - BRAZO_W;
			brazo->facingLeft = TRUE;

		}

		counter = 0;

	}


}

void brazoIA(Entity* enemy){

	if(enemy->bullet == ENEMY_NO_BULLET || globalEnemies[enemy->bullet].state == ENEMY_STATE_INACTIVE){

			setAnimation(enemy, A_brazo);

			if(enemy->finishedAnimation) {

				cpct_akp_SFXPlay(FX_BOLA_MAGO, 15, 33, 0, 0, AY_CHANNEL_B); 
				enemy->bullet = fire(enemy->xPos - enemy->width, enemy->yPos + 2, ENEMY_TYPE_BOLA, enemy->facingLeft);
				
			} 

	} else setAnimation(enemy, A_mano);

}

void enemyIA(Entity* enemy, Entity* hero){

	switch(enemy->type){

		case ENEMY_TYPE_BULLET:
		case ENEMY_TYPE_BOLA:

			leftToRight(enemy, FALSE);
			break;

		case ENEMY_TYPE_ARANA:
		case ENEMY_TYPE_PLATFORM:

			leftToRight(enemy, TRUE);
			break;

		case ENEMY_TYPE_VOLADOR:

			voladorIA(enemy, hero);
			break;

		case ENEMY_TYPE_ESQUELETO:

			esqueletoIA(enemy, hero);
			break;

		case ENEMY_TYPE_BRAZO:

			brazoIA(enemy);
			break;

		case ENEMY_TYPE_MAGO:

			magoIA(enemy, hero);
			break;

	}
}