//-----------------------------LICENSE NOTICE------------------------------------
//  This file is part of Jarlac
//  Copyright (C) 2018 Retrobytes Productions
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//------------------------------------------------------------------------------

#include "collision.h"

u8 obtenerTilePtr(i16 x, i16 y) {

	i16 X, Y;

	X = (x - MIN_X) / 8;
	Y = (y - MIN_Y) / 16;

	if(X > 9) X = 9;
	if(Y > 7) Y = 7;

	if(X < 0) X = 0;
	if(Y < 0) Y = 0;

	return G_currentMap[X + 10 * Y];

}

u8 checkProyection(i16 e1, i16 e2, i16 p1, i16 p2){

	return !(e2 < p1 || p2 < e1);

}

i8 onPlatform(Entity* entity, Entity *enemy){

	i8 response;
	u8 foot1, foot2, extreme1, extreme2, max, left;

	response = 0;
	max = MAX_ENEMIES;

	while(max){

		if(enemy->type == ENEMY_TYPE_PLATFORM && enemy->state > ENEMY_STATE_INACTIVE && entity->yPos + entity->height >= enemy->yPos && entity->yPos + entity->height <= enemy->yPos + enemy->height){

			foot1 = entity->xPos + 2;
			foot2 = entity->xPos + entity->width - 3;
			extreme1 = enemy->xPos;
			extreme2 = enemy->xPos + enemy->width;

			if(checkProyection(extreme1, extreme2, foot1, foot2)){

				left = enemy->facingLeft;

				if(onWall(enemy, FALSE) || (left && extreme1 == MIN_X) || (!left && extreme2 == MAX_X)) response = PLATFORM_ON_WALL;
				else response = enemy->xSpeed * (left ? -1:1);
				break;

			}

		}

		enemy++; max--;

	}

	return response;

}

u8 onRoof(Entity* entity){

	u8 tile, tile2;

	if(hearts == MAX_HEARTS && room == 14){

		return FALSE;
	}

	tile = obtenerTilePtr(entity->xPos + 2, entity->yPos);
	tile2 = obtenerTilePtr(entity->xPos + HERO_W - 3, entity->yPos);

	return (tile > 27 && tile < 31) || (tile2 > 27 && tile2 < 31);

}


u8 onFloor(Entity* entity){

	u8 tile, tile2;

	if(entity->yPos + entity->height > MAX_Y) return FALSE; 

	tile = obtenerTilePtr(entity->xPos + 3, entity->yPos + entity->height);
	tile2 = obtenerTilePtr(entity->xPos + entity->width - 3, entity->yPos + entity->height);
	
	return ((tile > 21 && tile < ENEMY_TYPE_AGUA) || (tile2 > 21 && tile2 < ENEMY_TYPE_AGUA));

}

u8 onSpecialTile(Entity* entity, u8 tileValue){


	u8 tile = obtenerTilePtr(entity->xPos + 3, entity->yPos + HERO_H);
	u8 tile2 = obtenerTilePtr(entity->xPos + HERO_W - 3, entity->yPos + entity->height);
	
	return tile == tileValue || tile2 == tileValue;

}

u8 onWall(Entity* entity, u8 checkFloors){

	u8 tile, tile2;

	if(hearts == MAX_HEARTS && room == 14){

		return FALSE;
	}

	if(entity->facingLeft){
	
		tile  = obtenerTilePtr(entity->xPos - 1, entity->yPos + entity->height - 6);
		tile2 = obtenerTilePtr(entity->xPos - 1, entity->yPos);

	}
	else{

		tile  = obtenerTilePtr(entity->xPos + entity->width, entity->yPos + entity->height - 6);
		tile2 = obtenerTilePtr(entity->xPos + entity->width, entity->yPos);

	}

	return (tile > 21 && tile < 32) || (tile2 > (checkFloors ? 21 : 27) && tile2 < 32);//(tile2 > 27 && tile2 < 31); //Los "suelos" no afectan a la comprobación de la cabeza

}

u8 onPlatformWall(Entity *entity, u8 facingLeft){

	u8 response;

	u8 backup = entity->facingLeft;

	entity->facingLeft = facingLeft;

	response = onWall(entity, TRUE);

	entity->facingLeft = backup;

	return response;
}

u8 nextToHole(Entity* entity){

	u8 tile;

	if(entity->facingLeft){

		tile = obtenerTilePtr(entity->xPos, entity->yPos + entity->height);

	}
	else{

		tile = obtenerTilePtr(entity->xPos + entity->width, entity->yPos + entity->height);

	}

	return (tile < 22 || tile == 31 || tile == ENEMY_TYPE_AGUA + 1 || tile == ENEMY_TYPE_LAVA + 1);

}

u8 checkCollision(Entity *enemy, Entity *player){


	i16 e1 = enemy->xPos;
	i16 e2 = enemy->xPos + enemy->width - 1;
	i16 p1 = player->xPos;
	i16 p2 = player->xPos + player->width - 1;

	if(!(enemy->checkCollisions || (enemy->type == ENEMY_TYPE_ESQUELETO && enemy->state == ENEMY_STATE_ATTACK)) || player->state >= HERO_STATE_HIT || !checkProyection(e1, e2, p1, p2)){

		return FALSE;

	}
	else{

		e1 = enemy->yPos;
		e2 = enemy->yPos + enemy->height - 1;
		p1 = player->yPos;
		p2 = player->yPos + player->height - 1;

		return checkProyection(e1, e2, p1, p2);

	}
	
}

u8 checkHit(Entity *enemy, Entity *player){

	i16 e1, e2, p1, p2;
	u8 *sprite;

	//if(player->state == HERO_STATE_FIRING){

		sprite = player->animation.frames[player->animation.frame]->sprite;

		if(sprite == G_jarlac_ataca2){

			e1 = enemy->xPos;
			e2 = enemy->xPos + enemy->width - 1;
			p1 = player->xPos;


			if(player->facingLeft){

				p1 -= DESTELLO_W;

			} 
			else{

				p1 += HERO_W;
				
			}

			p2 = p1 + DESTELLO_W - 1;


			if(!checkProyection(e1, e2, p1, p2)){

				return FALSE;
			}
			else{

				e1 = enemy->yPos;
				e2 = enemy->yPos + enemy->height - 1;
				p1 = player->yPos;
				p2 = player->yPos + player->height - 1;

				return checkProyection(e1, e2, p1, p2);

			}


		}	

	//}

	return FALSE;
}