//-----------------------------LICENSE NOTICE------------------------------------
//  This file is part of Jarlac
//  Copyright (C) 2018 Retrobytes Productions
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//------------------------------------------------------------------------------

#include "entities.h"

const Entity hero;
const Entity globalEnemies[MAX_ENEMIES];
const Entity globalLavas[MAX_LAVAS];

u8 gameOver;
u8 pause;
u32 score;
i8 energy;
u8 magic;
u8 lives;
u8 hearts;
Keys keys;
u8 room;
u8 earthQuake;
u8 interruptCounter;
u8 interruptPosition;
u16 screenAddress;
u8 end;
u8 music;
u8 inMenu;
u8 inMagic;
u8 fallDistance;
u8 topo;
Position enteringPosition;

void createEntity(Entity *entity, u8 entityType, i16 xPos, i16 yPos, u8 height, u8 width, u8 facingLeft, u8 hits, u8 checkCollisions, u8 xSpeed, u8 ySpeed, Frame **frames){

	entity->type			= entityType;
	entity->hits			= hits;
	entity->checkCollisions = checkCollisions;
	entity->xPos			= xPos;
	entity->yPos			= yPos;
	entity->width			= width;
	entity->height			= height;
	entity->state 			= ENEMY_STATE_ACTIVE;
	entity->xSpeed			= xSpeed;
	entity->ySpeed			= ySpeed;
	entity->facingLeft		= facingLeft;
	entity->alert			= FALSE;
	entity->bullet			= ENEMY_NO_BULLET;

	setAnimation(entity, frames);

}

u8 addEntity(u8 entityType, i16 xPos, i16 yPos, u8 facingLeft, Entity *enemy){

	u8 max = MAX_LAVAS;

    while(max){

        if(enemy->state == ENEMY_STATE_INACTIVE && enemy->pstate == ENEMY_STATE_INACTIVE){

        	switch (entityType) {

        		case ENEMY_TYPE_ARANA:

        			createEntity(enemy, ENEMY_TYPE_ARANA, xPos, yPos, ARANA_H, ARANA_W, facingLeft, 1, TRUE, ARANA_X_SPEED, 0, A_aranaWalk);

					break;

        		case ENEMY_TYPE_ESQUELETO:

        			createEntity(enemy, ENEMY_TYPE_ESQUELETO, xPos, yPos, ESQUELETO_H, ESQUELETO_W, facingLeft, 1, FALSE, ESQUELETO_X_SPEED, 0, A_esqueletoWalk);

        			break;

        		case ENEMY_TYPE_LAVA:

					createEntity(enemy, ENEMY_TYPE_LAVA, xPos, yPos, LAVA_H, LAVA_W, facingLeft, 0, FALSE, 0, 0, A_lava);

					break;

      			case ENEMY_TYPE_CORAZON:

      				createEntity(enemy, ENEMY_TYPE_CORAZON, xPos, yPos, CORAZON_H, CORAZON_W, FALSE, 0, TRUE, 0, 0, A_corazon);
   					break;

   				case ENEMY_TYPE_CORAZON_PIEDRA:

      				createEntity(enemy, ENEMY_TYPE_CORAZON_PIEDRA, xPos, yPos, CORAZON_H, CORAZON_W, FALSE, 0, FALSE, 0, 0, A_corazon_piedra);
   					
   					break;

   				case ENEMY_TYPE_VOLADOR:

      				createEntity(enemy, ENEMY_TYPE_VOLADOR, xPos, yPos, VOLADOR_H, VOLADOR_W, facingLeft, 1, TRUE, VOLADOR_X_SPEED, VOLADOR_Y_SPEED, A_volador);

   					break;

      			case ENEMY_TYPE_AGUA:

					createEntity(enemy, ENEMY_TYPE_AGUA, xPos, yPos, LAVA_H, LAVA_W, facingLeft, 0, FALSE, 0, 0, A_agua);

					break;

				case ENEMY_TYPE_PLATFORM:

		  			createEntity(enemy, ENEMY_TYPE_PLATFORM, xPos, yPos, PLATFORM_H, PLATFORM_W, facingLeft, 0, FALSE, PLATFORM_X_SPEED, PLATFORM_Y_SPEED, A_platform);

		  			break;

				case ENEMY_TYPE_MAGO:

		  			createEntity(enemy, ENEMY_TYPE_MAGO, xPos, yPos, MAGO_H, MAGO_W, facingLeft, 10, TRUE, MAGO_X_SPEED, MAGO_Y_SPEED, A_mago);

		  			break;

				case ENEMY_TYPE_BRAZO:

		  			createEntity(enemy, ENEMY_TYPE_BRAZO, xPos, yPos, BRAZO_H, BRAZO_W, facingLeft, 0, FALSE, MAGO_X_SPEED, MAGO_Y_SPEED, A_mano);

		  			break;

				case ENEMY_TYPE_BULLET:

        			createEntity(enemy, ENEMY_TYPE_BULLET, xPos, yPos, DAGA_H, DAGA_W, facingLeft, 1, TRUE, 3, 0, A_daga);

        			break;

				case ENEMY_TYPE_BOLA:

        			createEntity(enemy, ENEMY_TYPE_BOLA, xPos, yPos, BOLA_H, BOLA_W, facingLeft, 0, TRUE, BOLA_X_SPEED, 0, A_bola);

        			break;

        		case ENEMY_TYPE_CHOCHONA:

      				createEntity(enemy, ENEMY_TYPE_CHOCHONA, xPos, yPos, CHOCHONA_H, CHOCHONA_W, facingLeft, 0, FALSE, 0, 0, A_chochona1);

   					break;

				case ENEMY_TYPE_CHOCHONA_FREE:

      				createEntity(enemy, ENEMY_TYPE_CHOCHONA_FREE, xPos, yPos, CHOCHONA_H, CHOCHONA_W, facingLeft, 0, TRUE, 0, 0, A_chochona2);

   					break;

   				case ENEMY_TYPE_TOPO:

      				createEntity(enemy, ENEMY_TYPE_TOPO, xPos, yPos, TOPO_H, TOPO_W, FALSE, 0, TRUE, 0, 0, A_topo);

   					break;

			}

            break;

        }

        enemy++; max--;

    }

	return MAX_LAVAS - max;

}
