//-----------------------------LICENSE NOTICE------------------------------------
//  This file is part of Jarlac
//  Copyright (C) 2018 Retrobytes Productions
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//------------------------------------------------------------------------------

#include "move.h"

void changeHeartState(u8 state){

    u8 x;

    Heart *heart  = heartsList;

    for(x=0;x<MAX_HEARTS && heart->room <= room;x++){

        if(heart->room == room){

            heart->state = state;
          
            break;  
        }

        heart++;

    }

}

void reviveHero(Entity* hero){

	if(--lives == 0){

		gameOver = TRUE;

	}
	else{

		drawTileBox8x16(hero->xPos / 8, hero->yPos / 16, 2, 2, g_scrbuffers[0], FALSE);
		
		energy = MAX_ENERGY;

		hero->xPos = enteringPosition.xPos;
		hero->yPos = enteringPosition.yPos;
		hero->xSpeed = enteringPosition.xSpeed;
		hero->ySpeed = enteringPosition.ySpeed;
		hero->state = enteringPosition.state;
		hero->width = HERO_W;
		hero->height = HERO_H;

		if(enteringPosition.state == HERO_STATE_JUMPING_UP || enteringPosition.state == HERO_STATE_JUMPING_DOWN){

			setAnimation(hero, A_heroJump);

		}
		else setAnimation(hero, A_heroStand);

		drawRoom();
	}

	//updateScoreboard();
	updateEnergy();
	updateLives();
}


void jumpingUp(Entity *hero){

	fallDistance = 0;

	if(hero->ySpeed > 0){

		hero->yPos -= hero->ySpeed;
		hero->ySpeed -= HERO_JUMP_STEP;

		if(hero->ySpeed && onRoof(hero)){

			hero->ySpeed = 0;
			hero->state = HERO_STATE_JUMPING_DOWN;

			//Adjut to roof
			hero->yPos = MIN_Y + 16 * ((hero->yPos / 16) + 1);

		} 

		if(hero->yPos < MIN_Y - HERO_H){

			if(rooms[room].up != 255){

				hero->yPos = MAX_Y - HERO_H;
				room = rooms[room].up;

				drawRoom();

			}

		}
	}
	else{

		hero->state = HERO_STATE_JUMPING_DOWN;
		
	}

}

void killHero(Entity *hero){

	cpct_akp_SFXPlay(FX_MUERTE, 15, 52, 0, 0, AY_CHANNEL_B);

	hero->state = HERO_STATE_DEAD;
	setAnimation(hero, A_vapor);
	hero->width = VAPOR_W;
	hero->height = VAPOR_H;

}

void jumpingDown(Entity *hero){

	fallDistance++;

	if(onSpecialTile(hero, 31)){ //PINCHOS MORUNOS

		killHero(hero);

		return;

	}

	if(hero->yPos + HERO_H >= MAX_Y){

		if(onSpecialTile(hero, ENEMY_TYPE_AGUA + 1)){

			hero->state  = HERO_STATE_ON_FLOOR;
			hero->ySpeed = HERO_JUMP_SPEED;
			hero->yPos = MAX_Y - HERO_H + 4;

			return;

		}
		else if(onSpecialTile(hero, ENEMY_TYPE_LAVA + 1)){


				fallDistance = 0;

				killHero(hero);

				return;
		}

	}

	if(hero->yPos < MAX_Y){

		if(hero->ySpeed < 2 * HERO_JUMP_STEP || !(onFloor(hero) || onPlatform(hero, globalEnemies))){ //Corrector Layunta

			if(hero->ySpeed < HERO_JUMP_SPEED) hero->ySpeed += HERO_JUMP_STEP;
			hero->yPos += hero->ySpeed;
		}
		else{

			hero->state  = HERO_STATE_POST_JUMP;
			hero->ySpeed = HERO_JUMP_SPEED;

			setAnimation(hero, A_heroPreJump);

			if(fallDistance >= 16){

				cpct_akp_SFXPlay(FX_TERREMOTO, 15, 21, 0, 0, AY_CHANNEL_B);

				earthQuake = 4;

				energy-=10;
			
				if(energy < 0){

					energy = 2;
				
				} 
			
				//updateScoreboard();
				updateEnergy();

			} 

			fallDistance = 0;

		}
	}
	else{

		if(rooms[room].down != 255){

			hero->yPos = MIN_Y - HERO_H;
			room = rooms[room].down;

			drawRoom();

		}

	}

	//Adjuts to floor
	if(hero->ySpeed >= 2 * HERO_JUMP_STEP && (onFloor(hero) || onPlatform(hero, globalEnemies))){ //Corrector Layunta

		hero->yPos = MAX_Y - 16 * (((MAX_Y - hero->yPos + HERO_H) / 16) - 1) + 4;
	
	}

}

void heroDefault(Entity *hero){

	i8 onplatform;

	onplatform = onPlatform(hero, globalEnemies);

			
	if(!onFloor(hero) && !onplatform && !(hero->yPos == MAX_Y - HERO_H + 4)){ //La última condición solo se da cuando el heroe está en un tile especial

		hero->state = HERO_STATE_JUMPING_DOWN;
		setAnimation(hero, A_heroJump);
		hero->ySpeed = 0;
	}
	else{

		if(onplatform != PLATFORM_ON_WALL && !onPlatformWall(hero, onplatform < 0)) hero->xPos += onplatform;

		if(onSpecialTile(hero, 31)){ //PINCHOS MORUNOS

	 		
			killHero(hero);

	 	}

	 	if(onSpecialTile(hero, ENEMY_TYPE_AGUA + 1)){

	  			if(energy < MAX_ENERGY){

	  				energy++;
	  				//score += 10;
	  				updateEnergy();
	  				//updateScore();
	  			}
	  	} 


	}

}

void moveHero(Entity* hero){

	//hero->pxPos  = hero->xPos;
	hero->pyPos  = hero->yPos;
	hero->pstate = hero->state;
	hero->pwidth = hero->width;
	hero->pheight = hero->height;

	switch (hero->state) {

		case HERO_STATE_PRE_JUMP:

			hero->state = HERO_STATE_JUMPING_UP;
			setAnimation(hero, A_heroJump);

			break;

		case HERO_STATE_JUMPING_UP:

			jumpingUp(hero);

			break;

		case HERO_STATE_JUMPING_DOWN:

			jumpingDown(hero);

			break;

		case HERO_STATE_POST_JUMP:

			if(!earthQuake && hero->finishedAnimation){

				hero->state  = HERO_STATE_ON_FLOOR;
				setAnimation(hero, A_heroStand);

			}

			break;

		case HERO_STATE_DEAD:

			if(hero->finishedAnimation){

                reviveHero(hero);
            }

			break;

		default:

			heroDefault(hero);

			break;

	}

}

void killEnemy(Entity *enemy){

	enemy->state = ENEMY_STATE_EXPLOSION;
	setAnimation(enemy, A_vapor);
	enemy->width  = VAPOR_W;
	enemy->height = VAPOR_H;	

}

void moveEnemies(Entity *enemies, Entity *hero){

	Entity *brazo;

	u8 x = MAX_ENEMIES;

	Entity *enemy = enemies;

    while(x){

		enemy->pstate  = enemy->state;
		enemy->pxPos   = enemy->xPos;
		enemy->pyPos   = enemy->yPos;
		enemy->pwidth  = enemy->width;
		enemy->pheight = enemy->height;
		
    	switch (enemy->state) {

    		case ENEMY_STATE_ACTIVE:
    		case ENEMY_STATE_ATTACK:

				enemyIA(enemy, hero);

				if(enemy->hits && checkHit(enemy, hero)){

					score += 100 * enemy->hits;


					if(--enemy->hits == 0){

						//cpct_akp_SFXStopAll ();
						cpct_akp_SFXPlay(FX_MUERTE, 15, 45, 0, 0, AY_CHANNEL_B);

						killEnemy(enemy);

						if(enemy->type == ENEMY_TYPE_MAGO){

							brazo = &globalEnemies[2];
							brazo->state = ENEMY_STATE_INACTIVE;
							
						}
						else{

							magic += 8;
							if(magic > MAX_MAGIC) magic = MAX_MAGIC;
							updateMagic();

						}
						
					}

					updateScore();
				}

				if(checkCollision(enemy, hero)){

					if(enemy->type == ENEMY_TYPE_CORAZON){

						if(enemy->yPos + CORAZON_H + 1 == hero->yPos + HERO_H){

							enemy->state = ENEMY_STATE_INACTIVE;
							changeHeartState(HEART_STATE_COLLECTED);

							cpct_akp_SFXPlay(FX_GOLPE, 15, 45, 0, 0, AY_CHANNEL_B);

							hearts++;
							updateHearts();

						}

					}
					else if(enemy->type == ENEMY_TYPE_TOPO){

						enemy->state = ENEMY_STATE_INACTIVE;
						cpct_akp_SFXPlay(FX_GOLPE, 15, 45, 0, 0, AY_CHANNEL_B);
						topo = TRUE;

					}
					else{

						if(enemy->type == ENEMY_TYPE_BOLA) energy -= 4;
						else if(enemy->type == ENEMY_TYPE_BULLET){

							energy -= 2;
							enemy->state = ENEMY_STATE_EXPLOSION;
							cpct_akp_SFXPlay(FX_ESPADAZO, 15, 29, 0, 0, AY_CHANNEL_B);

						} 

						if(--energy <= 0){

							killHero(hero);
							
						} 

						updateEnergy();

					}
					
				}

				break;

    		case ENEMY_STATE_EXPLOSION:

				if(enemy->finishedAnimation){

					enemy->state = ENEMY_STATE_INACTIVE;

					if(enemy->type == ENEMY_TYPE_MAGO) end = TRUE;

				}

				break;
    	}

    	enemy++; x--;
    }

}
