//-----------------------------LICENSE NOTICE------------------------------------
//  This file is part of Jarlac
//  Copyright (C) 2018 Retrobytes Productions
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//------------------------------------------------------------------------------


#include "keyboard.h"

//Función proporcionada por ronaldo para redefinición de teclas
cpct_keyID esperaUnaTecla() {
    // Recorreremos el vector de teclas desde el final hacia el principio,
    // para poder hacer que el bucle acabe en 0 (así el compilador podrá optimizarlo)
    u8 i = 10, *keys = cpct_keyboardStatusBuffer + 9;
    u16 keypressed;

    // Esperamos hasta que se pulse una tecla
    while ( ! cpct_isAnyKeyPressed() );

    // Detectamos cuál tecla ha sido pulsada
    do {
        // Si en este grupo de 8 teclas hay una pulsada, alguno de los bits estará a 0
        // En caso contrario, todos estarán a 1, y un XOR con 0xFF dará 0 (FALSE) como resultado
        keypressed = *keys ^ 0xFF;
        if (keypressed)
            return (keypressed << 8) + (i - 1);  // Formato cpct_keyID: 8 primeros bits = máscara de tecla, 8 siguientes fila del teclado (0-9)
        keys--;
    } while(--i);

}

void waitKeyUp(cpct_keyID key) {

    while(cpct_isKeyPressed(key));

}

void checkKeyboardMenu() {

    static u8 selectedOption;

    drawSelector(selectedOption == 2 ? 0xC0 : 0x62, 29, 60);
    drawSelector(selectedOption == 2 ? 0x62 : 0xC0, 29, 80);

    if(cpct_isKeyPressed(Key_1)){

        selectedOption = 1;

        waitKeyUp(Key_1);

        keys.left  = Key_O;
        keys.right = Key_P;
        keys.up    = Key_Q;
        keys.down  = Key_A;
        keys.fire  = Key_Space;


    }

    else if(cpct_isKeyPressed(Key_2)){

        selectedOption = 2;

        waitKeyUp(Key_2);

        keys.left  = Joy0_Left;
        keys.right = Joy0_Right;
        keys.up    = Joy0_Up;
        keys.down  = Joy0_Down;
        keys.fire  = Joy0_Fire1;

    }
    else if(cpct_isKeyPressed(Key_3)){

      music = FALSE;
      cpct_akp_stop();

      cpct_setPalette(G_black_palette, 16);

    	decompress((u8*)EXO_JarlacIngame, (u8*)EXOBUFFER_ADDRESS);
    	cpct_akp_musicInit(G_JarlacIngame);

      music = TRUE;

   		game();

   		drawMenu();
      
    }

}

void checkCommonKeys(){


    if(cpct_isKeyPressed(Key_Esc)){

        gameOver = TRUE;

    }

    if(cpct_isKeyPressed(Key_Del)){

        pause = !pause;

        waitKeyUp(Key_Del);
    }

}

void left(Entity *hero){

  u8 wall;

  if(!hero->facingLeft){

    hero->facingLeft = TRUE;

  }

  wall = onWall(hero, FALSE);

  if(hero->state < HERO_STATE_PRE_JUMP) {

    if(!wall) hero->xPos -= HERO_WALK_SPEED;

    hero->state = HERO_STATE_GOING_LEFT;
    setAnimation(hero, A_heroWalk);
  }
  else if(!wall) hero->xPos -= HERO_JUMP_X_SPEED;

  if(hero->xPos <= MIN_X - HERO_W + 1){

    if(rooms[room].left != 255){

      //Tratamiento especial pantallas Árbol  

      if(rooms[room].left == 254){

        room = 15;
        hero->yPos = MIN_Y - HERO_H;
        
      }
      else if(rooms[room].left == 252){

        room = 35;
        hero->yPos = MIN_Y - HERO_H; 

      }
      else{

        room = rooms[room].left;

      }

      hero->xPos = MAX_X - HERO_W;
    
      drawRoom();

    }
    else{

      hero->xPos = MIN_X - HERO_W + 1;
    
    }

  }


}

void right(Entity *hero){

  u8 wall;

  if(hero->facingLeft){

    hero->facingLeft = FALSE;

  }

  wall = onWall(hero, FALSE);

  if(hero->state < HERO_STATE_PRE_JUMP){

    if(!wall) hero->xPos += HERO_WALK_SPEED;

    hero->state = HERO_STATE_GOING_RIGHT;
    setAnimation(hero, A_heroWalk);

  }
  else if(!wall) hero->xPos += HERO_JUMP_X_SPEED;

  if(hero->xPos >= MAX_X){

    if(rooms[room].right != 255){

      //Tratamiento especial pantallas Torreón  

      if(rooms[room].right == 253){

        room = 20;
        hero->yPos = MIN_Y - HERO_H;
        
      }
      else if(rooms[room].right == 252){

        room = 35;
        hero->yPos = MIN_Y - HERO_H; 

      }
      else{

        room = rooms[room].right;

      }

      hero->xPos = MIN_X;

      drawRoom();

    }
    else{

      hero->xPos = MAX_X;

    }

  }


}


void checkKeyboardGame(Entity *hero) {

    static u8 fireCycles;

    u8 fire = cpct_isKeyPressed(keys.fire);

    checkCommonKeys();

    hero->pstate = hero->state;
    hero->pxPos  = hero->xPos;
    hero->pyPos  = hero->pyPos;

    if(!pause && hero->state < HERO_STATE_HIT){

      if(hero->state < HERO_STATE_PRE_JUMP) hero->state = HERO_STATE_ON_FLOOR;

      if(fire){ 

          if(!fireCycles && hero->state < HERO_STATE_PRE_JUMP){

            cpct_akp_SFXPlay(FX_ESPADAZO, 15, 29, 0, 0, AY_CHANNEL_B);
            fireCycles = 10;

            hero->state = HERO_STATE_FIRING;
            setAnimation(hero, A_heroAtack);

          }

      }
      else if(cpct_isKeyPressed(keys.left)){


        left(hero);

      }

      else if(cpct_isKeyPressed(keys.right)){


        right(hero);

      }

      if(cpct_isKeyPressed(keys.up) && hero->state < HERO_STATE_PRE_JUMP){

            hero->state = HERO_STATE_PRE_JUMP;
            setAnimation(hero, A_heroPreJump);

      }
      else if(cpct_isKeyPressed(keys.down) && magic == MAX_MAGIC && hero->state < HERO_STATE_PRE_JUMP){

         //magia
         if(room != 14) inMagic = TRUE;

      }

      if(hero->state == HERO_STATE_ON_FLOOR && (hero->animation.frames != A_heroAtack || hero->finishedAnimation)){

          setAnimation(hero, A_heroStand);

      }

      if(fireCycles) fireCycles--;

    }
}
