//-----------------------------LICENSE NOTICE------------------------------------
//  This file is part of Jarlac
//  Copyright (C) 2018 Retrobytes Productions
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//------------------------------------------------------------------------------


#include "tilemaps.h"

//Hearts room, x, y, state
const Heart heartsList[MAX_HEARTS] = {

	{0, 5, 0, HEART_STATE_STONE},
	{1, 4, 1, HEART_STATE_STONE},
	{11, 2, 4, HEART_STATE_STONE},
	{13, 1, 2, HEART_STATE_STONE},
	{15, 6, 1, HEART_STATE_STONE},
	{21, 8, 1, HEART_STATE_STONE},
	{22, 4, 2, HEART_STATE_STONE},
	{35, 4, 0, HEART_STATE_STONE},
	{37, 7, 4, HEART_STATE_STONE},
	{39, 2, 2, HEART_STATE_STONE},
	{43, 7, 6, HEART_STATE_STONE},
	{57, 4, 6, HEART_STATE_STONE},
	{59, 3, 5, HEART_STATE_STONE}
};

//ROOMS left, right, up, down
const Room rooms[MAX_ROOMS] =

{
	{255, 253, 255, 5}, //0
	{255, 255, 255, 8}, //1
	{255, 3, 255, 10}, //2
	{2, 4, 255, 255}, //3
	{3, 5, 255, 255}, //4
	{4, 253, 0, 255}, //5
	{255, 7, 255, 22}, //6
	{6, 255, 255, 12}, //7
	{254, 9, 1, 16}, //8
	{8, 10, 255, 17}, //9
	{9, 11, 2, 255}, //10
	{10, 255, 255, 18}, //11
	{255, 13, 7, 255}, //12
	{12, 14, 255, 24}, //13
	{13, 15, 255, 255}, //14
	{14, 16, 255, 255}, //15
	{15, 17, 8, 255}, //16
	{16, 255, 9, 27}, //17
	{255, 19, 11, 29}, //18
	{18, 252, 255, 255}, //19
	{252, 21, 255, 255}, //20
	{20, 255, 255, 255}, //21
	{255, 23, 6, 255}, //22
	{22, 24, 255, 255}, //23
	{23, 25, 13, 255}, //24
	{24, 26, 255, 255}, //25
	{25, 255, 255, 31}, //26
	{255, 28, 17, 255}, //27
	{27, 29, 255, 32}, //28
	{28, 255, 18, 33}, //29
	{255, 31, 255, 40}, //30
	{30, 255, 26, 41}, //31
	{255, 33, 28, 255}, //32
	{32, 34, 29, 45}, //33
	{33, 35, 255, 255}, //34
	{34, 36, 255, 255}, //35
	{35, 37, 255, 255}, //36
	{36, 255, 255, 47}, //37
	{255, 39, 255, 48}, //38
	{38, 40, 255, 255}, //39
	{39, 255, 30, 255}, //40
	{255, 42, 31, 255}, //41
	{41, 43, 255, 51}, //42
	{42, 255, 255, 255}, //43
	{255, 45, 255, 53}, //44
	{44, 255, 33, 255}, //45
	{255, 47, 36, 255}, //46
	{46, 255, 37, 255}, //47
	{255, 49, 38, 255}, //48
	{48, 255, 255, 54}, //49
	{255, 51, 255, 56}, //50
	{50, 52, 42, 255}, //51
	{51, 53, 255, 57}, //52
	{52, 255, 44, 255}, //53
	{255, 55, 49, 255}, //54
	{54, 56, 255, 58}, //55
	{55, 255, 50, 255}, //56
	{255, 255, 52, 255}, //57
	{255, 255, 55, 59}, //58
	{255, 255, 58, 255} //59


};

const u8 G_currentMap[10 * 8] = {

	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0

};

u8* const G_levelMaps[MAX_ROOMS] = {

	G_map0,  G_map1,  G_map2,  G_map3,  G_map4,  G_map5,  G_map6,  G_map7,  G_map8,  G_map9,
	G_map10, G_map11, G_map12, G_map13, G_map14, G_map15, G_map16, G_map17, G_map18, G_map19,
	G_map20, G_map21, G_map22, G_map23, G_map24, G_map25, G_map26, G_map27, G_map28, G_map29,
	G_map30, G_map31, G_map32, G_map33, G_map34, G_map35, G_map36, G_map37, G_map38, G_map39,
	G_map40, G_map41, G_map42, G_map43, G_map44, G_map45, G_map46, G_map47, G_map48, G_map49,
	G_map50, G_map51, G_map52, G_map53, G_map54, G_map55, G_map56, G_map57, G_map58, G_map59

};	

const u8 G_tiles[8 * 16] = {
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0
};

// Tile G_tiles_01: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_01[8 * 16] = {
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf
};

// Tile G_tiles_02: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_02[8 * 16] = {
	0xcf, 0xcf, 0xcf, 0xce, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcc, 0xcc, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcc, 0xcc, 0xcf, 0xcf, 0xcf,
	0xcf, 0xce, 0xce, 0xcc, 0xcc, 0xcc, 0xcd, 0xcf,
	0xcf, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0x64, 0xcf,
	0xce, 0xcc, 0x64, 0x64, 0x64, 0x64, 0xce, 0xcd,
	0xcc, 0x64, 0xcd, 0xcd, 0xcd, 0xcd, 0x65, 0xcd,
	0xcd, 0xcd, 0xce, 0x65, 0xcf, 0xce, 0xce, 0xcf,
	0xce, 0xce, 0xcd, 0xce, 0xce, 0xcd, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcd, 0xcc, 0xcd, 0xcd, 0xcf,
	0xcf, 0xcf, 0xce, 0xce, 0x65, 0x64, 0x64, 0xce,
	0xcf, 0xcf, 0xcf, 0xcf, 0xce, 0xcf, 0xcd, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf
};

// Tile G_tiles_03: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_03[8 * 16] = {
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcc, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcc, 0x0c, 0xcc, 0xce, 0xcc, 0xcf, 0xcf,
	0xcf, 0x8e, 0x34, 0x18, 0x70, 0xcd, 0x98, 0xcf,
	0xcc, 0x98, 0x78, 0xe0, 0x1c, 0x18, 0x24, 0x64,
	0x9a, 0xb4, 0x78, 0xb0, 0x84, 0xe0, 0x94, 0xcd,
	0x9e, 0x78, 0xb0, 0xf0, 0x68, 0xf0, 0xb4, 0x4c,
	0xe0, 0xf0, 0x94, 0xe0, 0xf0, 0xd0, 0xb4, 0x78
};

// Tile G_tiles_04: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_04[8 * 16] = {
	0xe2, 0xb3, 0xc0, 0xb3, 0xe2, 0x62, 0xf3, 0xd1,
	0x73, 0x73, 0x73, 0x73, 0x91, 0xd1, 0x33, 0xb3,
	0x91, 0xbb, 0x91, 0x62, 0x62, 0xe2, 0x39, 0xe7,
	0xca, 0xb1, 0x62, 0xe2, 0x79, 0x73, 0xf1, 0xc5,
	0xca, 0xe2, 0xcf, 0xd1, 0xf1, 0xc5, 0x91, 0xef,
	0xca, 0xc0, 0xcf, 0xd1, 0x91, 0xc5, 0x91, 0xe5,
	0xca, 0x62, 0xcf, 0xd1, 0x91, 0xc0, 0x62, 0xcf,
	0xca, 0x62, 0xcf, 0xd1, 0x91, 0xc0, 0x62, 0xcf,
	0xca, 0xe2, 0xca, 0x62, 0xb7, 0xe8, 0xc0, 0xcf,
	0xca, 0xe2, 0xca, 0x62, 0x95, 0xb9, 0x67, 0xcf,
	0xcf, 0xd1, 0x91, 0x62, 0x67, 0xc0, 0xc5, 0xcf,
	0xcf, 0xd1, 0xd4, 0x3b, 0xca, 0xc0, 0xcf, 0xcf,
	0xcf, 0xca, 0xf6, 0x3b, 0xd1, 0x62, 0xcf, 0xcf,
	0xcf, 0xcf, 0xc0, 0xf3, 0xe2, 0xc5, 0xcf, 0xcf,
	0xcf, 0xcf, 0x91, 0x62, 0x62, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xca, 0xc0, 0xc5, 0xcf, 0xcf, 0xcf
};

// Tile G_tiles_05: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_05[8 * 16] = {
	0xcf, 0xcf, 0xcf, 0xd1, 0xc5, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0x91, 0x67, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0x91, 0xc5, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xca, 0x33, 0xc5, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xca, 0x91, 0x62, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0x91, 0xd1, 0x62, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xca, 0x62, 0xb3, 0xc5, 0xcf, 0xcf,
	0xcf, 0xcf, 0x67, 0x91, 0xc0, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xd5, 0x62, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xca, 0x37, 0x91, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0x91, 0xc5, 0x67, 0xcf, 0xcf,
	0xcf, 0xcf, 0xca, 0xb9, 0xc5, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xca, 0xf9, 0x62, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0x91, 0xc5, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xd1, 0xc5, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xca, 0xcf, 0xcf, 0xcf, 0xcf
};

// Tile G_tiles_06: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_06[8 * 16] = {
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xc5, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0x4d, 0xca, 0xcf,
	0x8e, 0xcf, 0xc5, 0xc5, 0xcf, 0x4d, 0x8e, 0xca,
	0x8e, 0xcf, 0xe5, 0xe5, 0xc5, 0xc5, 0x8e, 0x8e,
	0x8e, 0xcf, 0xe5, 0xe5, 0xc5, 0x4d, 0x8e, 0x8e,
	0x8e, 0xcf, 0xe5, 0xe5, 0xc5, 0x4d, 0xca, 0x8e,
	0x0c, 0xe5, 0xe5, 0xf8, 0xe5, 0x4d, 0x8e, 0x0c,
	0xc0, 0xd0, 0xf0, 0xe0, 0xd0, 0x58, 0x48, 0xc0,
	0xca, 0xca, 0xc0, 0xf0, 0xc0, 0xc0, 0xc0, 0xca,
	0x8e, 0xc8, 0xc8, 0x90, 0xe5, 0xca, 0x24, 0x8c,
	0xc8, 0x24, 0x70, 0xd8, 0xd8, 0x8c, 0xa4, 0x24,
	0x24, 0xa4, 0xf0, 0x34, 0x70, 0x24, 0x2c, 0xa4,
	0xa4, 0x2c, 0xf0, 0xb4, 0xf0, 0xa4, 0x2c, 0x2c,
	0x48, 0x48, 0x48, 0x48, 0xc0, 0x48, 0x48, 0x48
};

// Tile G_tiles_07: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_07[8 * 16] = {
	0xc0, 0xc2, 0x42, 0x6a, 0xc0, 0x6a, 0x81, 0xc0,
	0xd0, 0xc0, 0x95, 0xc0, 0x42, 0xc0, 0xc0, 0x42,
	0xe0, 0xe0, 0xc0, 0xc0, 0xc0, 0x81, 0xc0, 0xc0,
	0xc1, 0xc0, 0x42, 0x95, 0xc0, 0x42, 0xc2, 0xc0,
	0xc0, 0xd0, 0x85, 0xc2, 0x42, 0x83, 0x81, 0xc1,
	0xc0, 0x81, 0xcb, 0x81, 0xc2, 0x85, 0x42, 0xc0,
	0xc2, 0x85, 0x42, 0xc2, 0xc2, 0xc0, 0xc0, 0x42,
	0xc0, 0x81, 0x2b, 0xc3, 0x6a, 0x42, 0x81, 0x81,
	0xd0, 0xc0, 0xd0, 0x7a, 0xc0, 0xc0, 0xc0, 0x42,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0x42, 0xc1, 0xc0,
	0xc0, 0xe0, 0x81, 0x81, 0x81, 0xc0, 0xc0, 0x42,
	0xd4, 0x81, 0x42, 0x42, 0x81, 0xc1, 0xc1, 0xc2,
	0xd0, 0x03, 0xc2, 0xc1, 0xc1, 0xc2, 0xc2, 0xe0,
	0xc0, 0xe1, 0xc0, 0xc0, 0x95, 0x83, 0xc3, 0xea,
	0x6a, 0xc0, 0xc0, 0x95, 0xc0, 0xf0, 0xf4, 0xc0,
	0x95, 0xc0, 0x6a, 0x6a, 0xc0, 0xc0, 0xc0, 0xc0
};

// Tile G_tiles_08: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_08[8 * 16] = {
	0x7c, 0xf8, 0x94, 0x60, 0x78, 0xe0, 0xe0, 0xbc,
	0x94, 0xd0, 0xe8, 0xe0, 0x90, 0xd4, 0x90, 0x29,
	0x13, 0x56, 0xd0, 0xf4, 0xe8, 0xc0, 0x60, 0x42,
	0x91, 0xc0, 0xd0, 0xbc, 0x76, 0xe0, 0xd0, 0x81,
	0x42, 0xd6, 0xd4, 0x68, 0x72, 0xbc, 0x13, 0x42,
	0x81, 0xc0, 0xe8, 0x81, 0x23, 0x29, 0x81, 0xc0,
	0x42, 0x56, 0xbc, 0x42, 0x62, 0x42, 0xc2, 0x42,
	0xc0, 0xc0, 0x68, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0
};

// Tile G_tiles_09: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_09[8 * 16] = {
	0x34, 0x60, 0x68, 0x70, 0x78, 0x94, 0xd0, 0x68,
	0x90, 0xb4, 0x90, 0xb0, 0xe0, 0x62, 0xd0, 0x94,
	0x62, 0x70, 0x62, 0x39, 0xf4, 0xc0, 0xe0, 0x78,
	0xb4, 0x36, 0xd0, 0xb1, 0xb9, 0xc0, 0xb4, 0x72,
	0xf8, 0x32, 0x62, 0x68, 0xf1, 0xd4, 0x81, 0xd4,
	0xd4, 0x36, 0x76, 0xb1, 0xe0, 0x94, 0x42, 0xe8,
	0x62, 0x62, 0x34, 0xb9, 0xd0, 0xb1, 0x81, 0x81,
	0xc1, 0x62, 0x78, 0xd1, 0xe0, 0xe0, 0x62, 0x13,
	0xc0, 0x91, 0x74, 0xf4, 0xc0, 0xe8, 0x91, 0x62,
	0xc0, 0xc0, 0x34, 0xf8, 0xe0, 0x68, 0xc0, 0xc0,
	0xc0, 0xc0, 0x90, 0xfc, 0xd0, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0x90, 0xf8, 0xd4, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0x94, 0x7c, 0x94, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0x74, 0xe8, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0x3c, 0x68, 0xc0, 0xc0, 0xc0,
	0xc0, 0xc0, 0xc0, 0x94, 0xc0, 0xc0, 0xc0, 0xc0
};

// Tile G_tiles_10: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_10[8 * 16] = {
	0xe2, 0xb3, 0x8e, 0x84, 0x99, 0xcc, 0x8e, 0x84,
	0x59, 0xb3, 0x0c, 0x84, 0xcc, 0xcc, 0xda, 0x84,
	0x8e, 0x31, 0x9b, 0xc0, 0x84, 0x8c, 0x8e, 0x84,
	0xcf, 0x4d, 0x26, 0x84, 0x4c, 0xcd, 0x58, 0x84,
	0x8e, 0x9b, 0x48, 0xc0, 0x8c, 0xcf, 0xca, 0xca,
	0x0c, 0x0c, 0x26, 0xc0, 0x4d, 0x9b, 0x84, 0x84,
	0xd0, 0x91, 0x33, 0x91, 0x91, 0x91, 0xe0, 0xd0,
	0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0x91, 0xc0, 0xc0,
	0xcf, 0x91, 0x4c, 0xcc, 0xcd, 0x62, 0x4c, 0xcd,
	0xca, 0x48, 0x4c, 0xcc, 0xcd, 0x62, 0xc4, 0xc5,
	0x4d, 0x91, 0x4c, 0xcc, 0x4d, 0xca, 0x48, 0x4d,
	0x8e, 0x48, 0x0c, 0x8c, 0xcf, 0x33, 0x0c, 0x8e,
	0xcf, 0x48, 0x4c, 0x4d, 0x19, 0xca, 0x4d, 0x18,
	0x8e, 0x48, 0x0c, 0x8e, 0x26, 0x33, 0x0c, 0x73,
	0xe0, 0xe0, 0xd0, 0x91, 0xd1, 0xc0, 0x33, 0x33,
	0xc0, 0x91, 0xc0, 0xc0, 0x91, 0xc0, 0xc0, 0xc0
};

// Tile G_tiles_11: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_11[8 * 16] = {
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xce, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xce, 0x98, 0xcd, 0xcd, 0xcd, 0xcf, 0xcf, 0xcf,
	0xcf, 0x64, 0xce, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0x9a, 0xcd, 0xcf, 0xcf, 0xcf, 0xcd, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcd, 0xcf, 0x64, 0xce, 0xce,
	0xcf, 0xcf, 0xcf, 0xcf, 0xce, 0xcd, 0x65, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xce, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf
};

// Tile G_tiles_12: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_12[8 * 16] = {
	0x18, 0x3c, 0x19, 0x3c, 0x60, 0xc0, 0xb1, 0xb1,
	0x18, 0x0c, 0x39, 0x68, 0xc0, 0xf0, 0x91, 0xa4,
	0x18, 0x30, 0x3c, 0x39, 0x90, 0x78, 0xe0, 0xf0,
	0x32, 0x3c, 0x3c, 0x3c, 0x34, 0xf0, 0x91, 0xa4,
	0x0c, 0x3c, 0x3c, 0x3c, 0x3c, 0xe2, 0xe0, 0xa4,
	0x18, 0x1c, 0x3c, 0x3c, 0x3c, 0xd0, 0xc0, 0xa4,
	0xc8, 0x34, 0x3c, 0x3c, 0x68, 0xe0, 0xf0, 0x4d,
	0x60, 0x90, 0x3c, 0x3c, 0x3c, 0x94, 0xf0, 0x4d,
	0x18, 0x31, 0x3c, 0x3c, 0x78, 0x68, 0xd0, 0x4d,
	0xca, 0x39, 0x3c, 0x3c, 0x30, 0xd0, 0xd0, 0xe5,
	0x18, 0x3c, 0x3c, 0x3c, 0x94, 0x68, 0xb4, 0xa4,
	0x1c, 0x36, 0x78, 0x3c, 0x79, 0x94, 0x3c, 0x2c,
	0x3c, 0x91, 0x38, 0x3c, 0x78, 0x34, 0x0c, 0x78,
	0xc0, 0x36, 0x3c, 0x3c, 0x90, 0x94, 0xc0, 0x94,
	0x19, 0x32, 0x3c, 0x68, 0x68, 0x48, 0x62, 0xc0,
	0x31, 0x31, 0x3c, 0x33, 0x39, 0xd0, 0xc0, 0xc0
};

// Tile G_tiles_13: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_13[8 * 16] = {
	0x18, 0x7f, 0xe0, 0x3f, 0x94, 0xe2, 0xe0, 0xa4,
	0x18, 0x18, 0x32, 0x62, 0x78, 0xf0, 0x84, 0xa4,
	0x18, 0x31, 0x48, 0x31, 0x94, 0x70, 0xe0, 0xf0,
	0x32, 0x24, 0xc0, 0x91, 0xb4, 0xf0, 0x91, 0xa4,
	0x18, 0x0c, 0xc0, 0x91, 0x34, 0xe2, 0xe0, 0xa4,
	0x18, 0x2c, 0xc0, 0x91, 0x3c, 0xd0, 0xc0, 0xa4,
	0x8c, 0x24, 0xc0, 0x34, 0x94, 0xe0, 0xf0, 0x4d,
	0x64, 0xb0, 0xc0, 0x31, 0x94, 0xd0, 0xc0, 0xa4,
	0x18, 0x74, 0xb0, 0xe8, 0x78, 0x68, 0xe0, 0xa4,
	0x18, 0xf8, 0xfc, 0x36, 0x34, 0xd0, 0x68, 0xd0,
	0x58, 0x70, 0xbc, 0x72, 0x94, 0xb4, 0xb4, 0xa4,
	0x58, 0x78, 0xf8, 0x72, 0x79, 0x91, 0x68, 0x0c,
	0x58, 0x73, 0xe8, 0x73, 0x58, 0x36, 0xb6, 0x3c,
	0x36, 0x79, 0x79, 0xf9, 0x39, 0xf2, 0x72, 0xf2,
	0xf1, 0x76, 0x73, 0x91, 0x73, 0xf3, 0x33, 0xb3,
	0xb3, 0xb3, 0xb3, 0xb3, 0xb3, 0xb3, 0xf3, 0x73
};

// Tile G_tiles_14: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_14[8 * 16] = {
	0x42, 0xc0, 0xc0, 0x3f, 0xc0, 0x81, 0xc0, 0x7a,
	0xc0, 0x6a, 0x95, 0xb5, 0x6a, 0x17, 0x95, 0x3f,
	0x95, 0x3f, 0xd0, 0xf0, 0xab, 0xc0, 0xd0, 0xf5,
	0xc0, 0xe8, 0x03, 0xf4, 0x81, 0xd0, 0xc0, 0xe8,
	0x03, 0x81, 0x6a, 0x42, 0x17, 0xc0, 0xe0, 0x81,
	0x6a, 0x52, 0x7a, 0x81, 0x3f, 0x6a, 0x03, 0x17,
	0x3f, 0xc0, 0xe0, 0xc0, 0xd0, 0x81, 0x6a, 0x3f,
	0xb5, 0x95, 0x81, 0x03, 0xc0, 0x17, 0xc0, 0xf0,
	0xa9, 0x03, 0x42, 0x6a, 0x03, 0x3f, 0xe0, 0xd0,
	0x42, 0x95, 0x95, 0x3f, 0xc0, 0xd0, 0xc0, 0x03,
	0x6a, 0xe0, 0xd5, 0xf0, 0xd0, 0xc0, 0x81, 0xc0,
	0xc0, 0x81, 0x42, 0xe8, 0x03, 0x42, 0x57, 0xc0,
	0xe0, 0x17, 0x81, 0x03, 0x3f, 0x81, 0x3f, 0xe8,
	0x03, 0x7a, 0x2b, 0xd0, 0xb5, 0x6a, 0xb5, 0xe0,
	0x6a, 0x7a, 0xa1, 0xd0, 0xb5, 0xe8, 0xd0, 0x03,
	0xc0, 0xd0, 0x42, 0xc0, 0x7e, 0x81, 0x03, 0xc0
};

// Tile G_tiles_15: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_15[8 * 16] = {
	0x33, 0xc0, 0xc0, 0xd1, 0xc0, 0xd1, 0xc0, 0x33,
	0x62, 0x62, 0x91, 0xc0, 0x84, 0xc0, 0x84, 0x91,
	0xb3, 0xc0, 0x62, 0xe2, 0x19, 0xc0, 0xc0, 0x19,
	0xc0, 0xc0, 0x73, 0xc0, 0xb3, 0x91, 0xc0, 0xb3,
	0xc0, 0x62, 0xc0, 0xc0, 0xb1, 0x91, 0x62, 0xd1,
	0x91, 0x91, 0xc0, 0x72, 0x31, 0x62, 0x62, 0x68,
	0x91, 0xb3, 0x91, 0x72, 0xfc, 0xe0, 0xc0, 0xc0,
	0xc0, 0x62, 0x91, 0x91, 0xf0, 0x62, 0xd1, 0xc0,
	0xc0, 0xd5, 0x6a, 0x91, 0xc0, 0x90, 0x62, 0xe2,
	0x91, 0x95, 0x3b, 0x62, 0x62, 0xc0, 0x33, 0xc0,
	0x62, 0x62, 0xc0, 0xb3, 0xc0, 0x62, 0xc0, 0xc0,
	0xb3, 0x62, 0xc0, 0xc0, 0x91, 0x84, 0xc0, 0x4a,
	0xd1, 0xc0, 0x68, 0x84, 0xc0, 0x33, 0xc1, 0x85,
	0xc0, 0xc0, 0xc0, 0x48, 0xe2, 0xb3, 0xc0, 0xc3,
	0xc0, 0xc0, 0x4a, 0x33, 0xe2, 0xd1, 0xc0, 0xc3,
	0x33, 0xc1, 0xc1, 0xb3, 0x62, 0xc0, 0xc0, 0xc1
};

// Tile G_tiles_16: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_16[8 * 16] = {
	0x33, 0xc1, 0xc2, 0xd1, 0xc0, 0xd1, 0xc0, 0x33,
	0x48, 0x62, 0x84, 0xc0, 0x91, 0xc0, 0x91, 0x91,
	0x9b, 0xc0, 0x48, 0xe2, 0x33, 0xc0, 0xc0, 0x33,
	0x8e, 0xc0, 0x73, 0xc0, 0xb3, 0xc1, 0xc0, 0x73,
	0x67, 0x91, 0x91, 0x91, 0xd1, 0x85, 0xc2, 0xd1,
	0x9b, 0x62, 0xe2, 0x33, 0xc0, 0xc0, 0x4a, 0x68,
	0x8e, 0x73, 0xc0, 0xe2, 0x90, 0xc0, 0xc0, 0xc0,
	0xcf, 0x62, 0xc0, 0xc0, 0x62, 0x62, 0xd1, 0xc0,
	0xcf, 0x67, 0x91, 0x84, 0x62, 0xc0, 0x62, 0xe2,
	0xcf, 0xcf, 0x33, 0xe0, 0x48, 0xc0, 0x33, 0xc0,
	0xcf, 0x9b, 0x32, 0x78, 0xc0, 0x62, 0xc0, 0xc0,
	0xcf, 0xcf, 0xb4, 0x78, 0x91, 0x91, 0xc0, 0xe2,
	0xcf, 0xcf, 0xda, 0xe5, 0x26, 0x9b, 0x91, 0xd1,
	0xcf, 0xcf, 0xcf, 0xcf, 0x67, 0x9b, 0xc0, 0x33,
	0xcf, 0xcf, 0xcf, 0xcf, 0x4d, 0x4d, 0xc0, 0x33,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0x9b, 0x9b
};

// Tile G_tiles_17: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_17[8 * 16] = {
	0x33, 0xc0, 0xe2, 0xc0, 0xe2, 0xc0, 0xc0, 0x33,
	0x62, 0x62, 0xc0, 0x62, 0xc0, 0x48, 0x91, 0x84,
	0x33, 0xc0, 0xc0, 0x33, 0xd1, 0x84, 0xc0, 0x33,
	0xb3, 0xc0, 0xc2, 0x73, 0xc0, 0xb3, 0xc0, 0x9b,
	0xe2, 0xc1, 0x4a, 0xe2, 0x62, 0x62, 0x62, 0x4d,
	0xc1, 0x85, 0xc0, 0xc0, 0xc0, 0xd1, 0x91, 0x67,
	0xc0, 0xc0, 0x60, 0x33, 0xd1, 0xc0, 0xb3, 0x4d,
	0xc0, 0xe2, 0x91, 0x62, 0xe2, 0x62, 0x91, 0x9b,
	0xd1, 0x91, 0xc0, 0x62, 0x33, 0x62, 0x9b, 0xcf,
	0xc0, 0x26, 0xc0, 0xc0, 0x33, 0x70, 0xcf, 0xcf,
	0xc0, 0xc0, 0x91, 0xc0, 0xb4, 0x78, 0x67, 0xcf,
	0xd1, 0xc0, 0x62, 0x62, 0xd0, 0xe5, 0xcf, 0xcf,
	0xe2, 0x62, 0x26, 0x33, 0x9b, 0xcf, 0xcf, 0xcf,
	0x33, 0xc0, 0x4d, 0x8e, 0xcf, 0xcf, 0xcf, 0xcf,
	0x19, 0xc0, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0x8e, 0x67, 0x4d, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf
};

// Tile G_tiles_18: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_18[8 * 16] = {
	0x8e, 0x67, 0x4d, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0x19, 0xc0, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0x33, 0xc0, 0x4d, 0x8e, 0xcf, 0xcf, 0xcf, 0xcf,
	0xe2, 0x62, 0x26, 0x33, 0x9b, 0xcf, 0xcf, 0xcf,
	0xd1, 0xc0, 0x62, 0x62, 0x33, 0x4d, 0xcf, 0xcf,
	0xc0, 0xd0, 0x91, 0xc0, 0xc0, 0x19, 0x67, 0xcf,
	0xc0, 0xf5, 0xe0, 0xc0, 0x33, 0x91, 0xcf, 0xcf,
	0xd1, 0xd0, 0xc0, 0x62, 0x33, 0x62, 0x9b, 0xcf,
	0xc0, 0xe2, 0x91, 0x62, 0xe2, 0x62, 0x91, 0x9b,
	0xc0, 0xc0, 0x60, 0x33, 0xd1, 0xc0, 0xb3, 0x4d,
	0xc1, 0x85, 0xc0, 0xc0, 0xf0, 0xdb, 0x91, 0x67,
	0xe2, 0xc1, 0x4a, 0xf2, 0xbe, 0xe0, 0x62, 0x4d,
	0xb3, 0xc0, 0xc2, 0x72, 0x7f, 0xb1, 0xc0, 0x9b,
	0x33, 0xc0, 0xc0, 0x33, 0xf0, 0x84, 0xc0, 0x33,
	0x62, 0x62, 0xc0, 0x62, 0xc0, 0x48, 0x91, 0x84,
	0x33, 0xc0, 0xe2, 0xc0, 0xe2, 0xc0, 0xc0, 0x33
};

// Tile G_tiles_19: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_19[8 * 16] = {
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0x8e, 0x8f, 0x4d,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xc0, 0x26,
	0xcf, 0xcf, 0xcf, 0xcf, 0x4d, 0x8e, 0xc0, 0xb3,
	0xcf, 0xcf, 0xcf, 0x4f, 0x0f, 0x0d, 0xd1, 0xd1,
	0xcf, 0xcf, 0x8e, 0x0f, 0x91, 0x91, 0xc0, 0xe2,
	0xcf, 0x8f, 0x0e, 0xc0, 0xc0, 0xe2, 0xfc, 0xc0,
	0xcf, 0xcf, 0x60, 0x5b, 0xc0, 0xd4, 0x34, 0xe0,
	0xcf, 0x4f, 0x85, 0xb3, 0x91, 0xd4, 0x3c, 0xe2,
	0x4f, 0x4a, 0x91, 0xd1, 0xd1, 0x62, 0xf1, 0xc0,
	0x8e, 0x5b, 0xc0, 0xe2, 0xb3, 0x90, 0xc0, 0xc0,
	0x8f, 0x4a, 0xe7, 0x91, 0xc0, 0xc0, 0x4a, 0xc2,
	0x8e, 0x85, 0xc0, 0xe2, 0xb3, 0x85, 0xc2, 0xd1,
	0x4f, 0xc0, 0xe2, 0x73, 0x91, 0xc1, 0xc0, 0x73,
	0x0f, 0xc0, 0x48, 0x91, 0xc0, 0xc0, 0xc0, 0x33,
	0x48, 0x4a, 0x84, 0xc0, 0x91, 0xc0, 0x91, 0x91,
	0x1b, 0xd1, 0xc0, 0xd1, 0xc0, 0xd1, 0xc0, 0x33
};

// Tile G_tiles_20: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_20[8 * 16] = {
	0x94, 0x3c, 0xc5, 0xcf, 0xcf, 0xca, 0x3c, 0x33,
	0x94, 0x39, 0xc0, 0xc0, 0xc0, 0xd1, 0x39, 0x62,
	0x94, 0xb4, 0x91, 0x30, 0x30, 0x31, 0xf2, 0x62,
	0x94, 0x34, 0x91, 0x33, 0x39, 0x68, 0x32, 0x62,
	0x94, 0x79, 0x36, 0x36, 0x3c, 0x68, 0x33, 0x68,
	0x91, 0x39, 0x94, 0x3c, 0x3c, 0x68, 0x39, 0x68,
	0x33, 0xb3, 0xc0, 0xc0, 0xc0, 0xc0, 0x39, 0x68,
	0x73, 0x36, 0xc0, 0x9b, 0xcf, 0xc0, 0xb6, 0x68,
	0x91, 0x36, 0x90, 0x67, 0x33, 0x68, 0x73, 0xe2,
	0x94, 0x73, 0x91, 0x60, 0x94, 0x33, 0x39, 0x62,
	0x94, 0x33, 0xc0, 0x38, 0x72, 0xc0, 0x39, 0x39,
	0x94, 0x36, 0xc5, 0x91, 0x60, 0xca, 0x3c, 0x62,
	0x94, 0x36, 0x91, 0x68, 0x38, 0x62, 0x3c, 0x62,
	0x94, 0x3c, 0x94, 0x62, 0x91, 0x60, 0x3c, 0x68,
	0x94, 0x3c, 0xd0, 0xc5, 0x62, 0x68, 0x3c, 0x68,
	0x94, 0x3c, 0xc0, 0x9b, 0x9b, 0xc0, 0x3c, 0x68
};

// Tile G_tiles_21: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_21[8 * 16] = {
	0xb3, 0xf3, 0x73, 0x33, 0x73, 0xb3, 0x73, 0x33,
	0x73, 0xb3, 0xb3, 0xf3, 0xb3, 0xf3, 0xb3, 0xf3,
	0xf3, 0xf3, 0xf3, 0xf3, 0xf3, 0xf3, 0xf3, 0xf3,
	0xf3, 0xf3, 0xf3, 0xf3, 0xf3, 0xf3, 0xf3, 0xf3,
	0xf3, 0x71, 0xf3, 0xf3, 0xf3, 0xb2, 0xf3, 0xf3,
	0x30, 0x71, 0x71, 0xb2, 0x71, 0x30, 0x30, 0x71,
	0x32, 0x32, 0x32, 0x30, 0x32, 0x33, 0x31, 0x30,
	0x91, 0x91, 0x91, 0x91, 0x91, 0xe2, 0x62, 0x62,
	0x62, 0x62, 0x62, 0xc0, 0x62, 0x62, 0x91, 0x91,
	0x91, 0xc0, 0xe2, 0x62, 0xc0, 0x62, 0x62, 0x62,
	0x91, 0x91, 0xc0, 0xb3, 0x91, 0xd1, 0x33, 0xe2,
	0x91, 0xc0, 0x91, 0xd1, 0x62, 0x62, 0xe2, 0x91,
	0x62, 0xe2, 0x33, 0xc0, 0xc0, 0x62, 0xc0, 0x91,
	0x91, 0xc0, 0x73, 0x91, 0xc0, 0xc0, 0xc0, 0x73,
	0x91, 0x91, 0xe2, 0x62, 0x62, 0x91, 0x91, 0xe2,
	0x62, 0x62, 0xc0, 0x62, 0xc0, 0x62, 0xc0, 0xc0
};

// Tile G_tiles_22: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_22[8 * 16] = {
	0xc0, 0xcc, 0xc8, 0xc0, 0xc0, 0xc0, 0xc8, 0xc0,
	0x84, 0xcc, 0xcc, 0xc4, 0xcc, 0xc4, 0xcc, 0xc4,
	0xc8, 0x4c, 0xc8, 0x8c, 0xcc, 0xc8, 0x48, 0xcc,
	0xcc, 0xc0, 0xc4, 0x4c, 0xcc, 0xcc, 0xc4, 0xcc,
	0xcc, 0xcc, 0xc4, 0xcc, 0xcc, 0xcc, 0xc4, 0xcc,
	0xcc, 0xc8, 0x8c, 0xcc, 0xcc, 0x8c, 0xc8, 0xcc,
	0xcc, 0xc4, 0xcc, 0xcc, 0xcc, 0xcc, 0xc8, 0xcc,
	0xc0, 0xc0, 0xcc, 0xcc, 0xcc, 0xc8, 0x48, 0x4c,
	0x48, 0x48, 0xc4, 0xcc, 0x84, 0x84, 0x48, 0xc0,
	0xc0, 0xc0, 0x48, 0xc0, 0x0c, 0x84, 0x48, 0x84,
	0x48, 0x84, 0x84, 0x48, 0x48, 0x0c, 0xc0, 0x0c,
	0x0c, 0xc0, 0x48, 0x0c, 0x84, 0x0c, 0x94, 0x84,
	0x2c, 0xc0, 0x2c, 0x0c, 0x94, 0x1c, 0x84, 0x48,
	0x34, 0x48, 0x90, 0x2c, 0x2c, 0x38, 0x94, 0x38,
	0x90, 0x38, 0xc0, 0x30, 0x94, 0x60, 0x3c, 0x60,
	0xc0, 0x60, 0xc0, 0xc0, 0x30, 0xc0, 0x90, 0xc0
};

// Tile G_tiles_23: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_23[8 * 16] = {
	0x33, 0xf3, 0x73, 0x33, 0x73, 0x73, 0xd9, 0x33,
	0xd9, 0x33, 0xb3, 0xf3, 0xb3, 0xb3, 0x66, 0xf3,
	0x33, 0xe2, 0x62, 0xb3, 0x66, 0x33, 0xd9, 0x33,
	0xd1, 0x73, 0xd1, 0x73, 0xd1, 0x62, 0xb3, 0xe2,
	0x99, 0x99, 0x99, 0x91, 0x91, 0xe2, 0x62, 0x66,
	0xc8, 0xc0, 0x62, 0xc8, 0xc8, 0x66, 0xc4, 0xc4,
	0xcc, 0xc4, 0x62, 0xcc, 0xcc, 0x66, 0xc8, 0xcc,
	0x8c, 0x91, 0xc4, 0xcc, 0xcc, 0xc4, 0xc0, 0xc0,
	0xc0, 0x91, 0xc0, 0x48, 0xcc, 0xc8, 0x84, 0x84,
	0x48, 0x91, 0xc0, 0x0c, 0xc0, 0x84, 0xc0, 0xc0,
	0x0c, 0x62, 0x0c, 0x84, 0x84, 0x48, 0x48, 0x84,
	0x48, 0x68, 0x0c, 0x48, 0x0c, 0x84, 0xc0, 0x0c,
	0x84, 0x48, 0x2c, 0x68, 0x0c, 0x1c, 0xc0, 0x1c,
	0x34, 0x68, 0x34, 0x1c, 0x1c, 0x60, 0x84, 0x38,
	0x90, 0x3c, 0x90, 0x68, 0x30, 0xc0, 0x34, 0x60,
	0xc0, 0x60, 0xc0, 0x30, 0xc0, 0xc0, 0x90, 0xc0
};

// Tile G_tiles_24: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_24[8 * 16] = {
	0xc0, 0xc0, 0xc5, 0xcf, 0xcf, 0xca, 0xc0, 0xc0,
	0x90, 0x30, 0xc0, 0xc0, 0xc0, 0xd1, 0x30, 0x60,
	0x94, 0x3c, 0x91, 0x30, 0x30, 0x31, 0xb3, 0x62,
	0x91, 0x3c, 0x91, 0x36, 0x3c, 0x68, 0x36, 0x68,
	0x94, 0x3c, 0x94, 0x3c, 0x36, 0x68, 0x3c, 0x68,
	0x94, 0x39, 0x94, 0x3c, 0x3c, 0x68, 0x39, 0x68,
	0x94, 0xb3, 0x94, 0x3c, 0x3c, 0x68, 0x39, 0x68,
	0xd1, 0x33, 0x91, 0x36, 0x3c, 0x68, 0xb6, 0x68,
	0x90, 0x30, 0xd1, 0x33, 0x36, 0xb3, 0x30, 0x60,
	0xc0, 0xc0, 0xb3, 0x30, 0x71, 0x62, 0xc0, 0xc0,
	0x94, 0x39, 0x62, 0x62, 0xc0, 0x62, 0xb3, 0x39,
	0x94, 0x79, 0x36, 0x36, 0x3c, 0x62, 0x79, 0x62,
	0x73, 0xb3, 0x94, 0x39, 0x73, 0x68, 0x33, 0x68,
	0x91, 0x36, 0x94, 0x62, 0x91, 0xe2, 0x36, 0x68,
	0x91, 0x39, 0x91, 0xc5, 0xca, 0x62, 0x36, 0x68,
	0x94, 0x39, 0xc0, 0xcf, 0xcf, 0xc0, 0x3c, 0x68
};

// Tile G_tiles_25: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_25[8 * 16] = {
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xca, 0xc0, 0xcf, 0xcf, 0xcf, 0xcf, 0xc0, 0xc5,
	0x90, 0x30, 0xc5, 0xca, 0xc0, 0xca, 0x30, 0x60,
	0x90, 0x3c, 0xc0, 0x90, 0x30, 0xc0, 0x94, 0x68,
	0x94, 0x68, 0x91, 0x90, 0x68, 0xc0, 0x34, 0x62,
	0x91, 0x3c, 0xc0, 0xc0, 0x3c, 0xc0, 0x3c, 0x68,
	0xc0, 0xc0, 0x91, 0x91, 0x36, 0xc0, 0xc0, 0xc0,
	0xd0, 0xf0, 0xc0, 0xc0, 0xc0, 0xc0, 0xf0, 0xe0,
	0xd0, 0xb4, 0xc0, 0xd0, 0xf0, 0x91, 0xf0, 0x68,
	0xd0, 0x3c, 0xc0, 0xd0, 0xb4, 0xc0, 0xb4, 0x68,
	0x62, 0x68, 0xcf, 0xd0, 0x3c, 0x91, 0x94, 0xc5,
	0x67, 0xc5, 0xcf, 0xca, 0x68, 0x9b, 0xca, 0xcf,
	0x67, 0x33, 0xcf, 0x67, 0xc5, 0xcf, 0xcf, 0xcf,
	0xcf, 0x67, 0x33, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf
};

// Tile G_tiles_26: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_26[8 * 16] = {
	0x4d, 0xcf, 0x0c, 0x0c, 0x8e, 0xcf, 0xcf, 0xcf,
	0x2c, 0x0c, 0xb2, 0x30, 0x59, 0x0c, 0x8e, 0x0c,
	0xb0, 0x70, 0x36, 0xb4, 0x3c, 0xb2, 0x18, 0xb4,
	0x3c, 0x94, 0x72, 0xf0, 0x68, 0x36, 0x3c, 0x3c,
	0xf0, 0xf0, 0x67, 0x65, 0xf0, 0x72, 0xd0, 0xb4,
	0xcf, 0x65, 0x67, 0x65, 0x9a, 0x32, 0x67, 0x70,
	0xcf, 0xcf, 0x67, 0x9a, 0x65, 0x32, 0xcf, 0x65,
	0xcf, 0xcf, 0x67, 0xcf, 0xcf, 0x9a, 0xcf, 0xcf,
	0xcf, 0xcf, 0x67, 0xcf, 0xcf, 0x9a, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf,
	0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf, 0xcf
};

// Tile G_tiles_27: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_27[8 * 16] = {
	0xcc, 0xcc, 0x8c, 0xc0, 0x84, 0x8c, 0xcc, 0xc8,
	0xcc, 0x8c, 0xcc, 0x48, 0x4c, 0x4c, 0xcc, 0x8c,
	0xcc, 0xcc, 0x4d, 0xc0, 0x0c, 0xcc, 0xcc, 0xcc,
	0xcc, 0xcc, 0xcc, 0x48, 0x4c, 0x4c, 0xcc, 0xcc,
	0xcc, 0xc8, 0xcd, 0x48, 0x0c, 0xcc, 0xcc, 0xcc,
	0xcc, 0x8c, 0xcd, 0x48, 0x4c, 0xcc, 0xcc, 0x4c,
	0xcc, 0xcc, 0xc8, 0x48, 0x0c, 0xcc, 0xcc, 0xcc,
	0xcc, 0xcc, 0x8e, 0xc0, 0x4c, 0xcc, 0xcc, 0xcc,
	0x4d, 0xcd, 0xcf, 0x48, 0x4d, 0x4d, 0xcd, 0xcd,
	0xcc, 0x8e, 0x8e, 0x48, 0x84, 0x84, 0x8c, 0xcf,
	0x4d, 0x4d, 0x4d, 0x48, 0xc0, 0x0c, 0x4d, 0x0c,
	0x84, 0x84, 0x8e, 0xc0, 0xa4, 0xc0, 0x84, 0x0c,
	0x48, 0xc0, 0xc0, 0xd0, 0xf8, 0xc0, 0x62, 0x48,
	0x91, 0x91, 0x91, 0x62, 0xe0, 0xd1, 0x3b, 0xc0,
	0xd1, 0x33, 0xc0, 0xd1, 0xd1, 0xb7, 0xbf, 0x62,
	0xca, 0xe2, 0xd4, 0xe0, 0xe2, 0xc0, 0x6a, 0x91
};

// Tile G_tiles_28: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_28[8 * 16] = {
	0x60, 0x34, 0x68, 0xc0, 0x94, 0xc0, 0x90, 0x68,
	0x38, 0x3c, 0x3c, 0x90, 0x60, 0x68, 0x68, 0x34,
	0x34, 0x3d, 0x60, 0x34, 0x3c, 0x95, 0x90, 0x3a,
	0x3e, 0x3f, 0x68, 0x34, 0x68, 0x68, 0x95, 0x94,
	0x94, 0xba, 0x90, 0x3c, 0x3c, 0xd5, 0x91, 0xea,
	0x3e, 0x7b, 0x32, 0x34, 0x68, 0xea, 0x6a, 0xd5,
	0x3d, 0x30, 0xb7, 0x30, 0x3c, 0xd5, 0xb3, 0xe2,
	0x90, 0x60, 0x39, 0x34, 0x60, 0xea, 0x7b, 0x94,
	0x34, 0x3c, 0x77, 0x30, 0x68, 0x94, 0x91, 0x68,
	0x34, 0x38, 0x7b, 0x32, 0x60, 0x68, 0x7b, 0x94,
	0x94, 0x3c, 0x95, 0x6a, 0x30, 0xd5, 0x90, 0xc0,
	0x34, 0x38, 0xbf, 0xc0, 0xc0, 0x6a, 0x34, 0x3e,
	0x34, 0x94, 0xbf, 0x90, 0x3d, 0x95, 0x30, 0x68,
	0x34, 0xbf, 0x95, 0x3c, 0x3c, 0xc0, 0x34, 0x68,
	0x3a, 0x3f, 0x6a, 0x34, 0x3d, 0x34, 0x38, 0x68,
	0x95, 0xc0, 0x94, 0x90, 0x6a, 0x90, 0x94, 0xc0
};

// Tile G_tiles_29: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_29[8 * 16] = {
	0x3c, 0x68, 0x3d, 0x95, 0x90, 0xc0, 0x35, 0x94,
	0x34, 0xc0, 0xe2, 0xea, 0x74, 0x34, 0x3c, 0x95,
	0x3a, 0x38, 0xd1, 0x91, 0x38, 0x3e, 0xea, 0x68,
	0xd5, 0x3c, 0x32, 0x60, 0x3d, 0x39, 0x90, 0x3c,
	0x95, 0x74, 0xd5, 0x38, 0x3e, 0x6a, 0x34, 0x7d,
	0x90, 0xb8, 0x68, 0xbe, 0x95, 0x33, 0x3c, 0xbf,
	0x6a, 0x35, 0x3d, 0x6a, 0x60, 0xe2, 0xbe, 0x6a,
	0xd1, 0x3e, 0x68, 0x90, 0x3c, 0x90, 0x95, 0x90,
	0x68, 0xb6, 0x95, 0x3c, 0x3d, 0x36, 0x60, 0x34,
	0x7d, 0x62, 0x60, 0xea, 0xbf, 0xc0, 0x68, 0x95,
	0xea, 0x30, 0x3c, 0xd5, 0x6a, 0x37, 0xd5, 0x68,
	0x95, 0x94, 0x3c, 0x6a, 0xd5, 0xc0, 0xbe, 0x34,
	0x6a, 0x6a, 0x68, 0x95, 0x6a, 0x6a, 0x68, 0x68,
	0x95, 0x95, 0x90, 0x3c, 0x95, 0x94, 0x34, 0x60,
	0x3e, 0x60, 0x62, 0x60, 0x68, 0xc0, 0x38, 0x60,
	0x90, 0xd1, 0xba, 0x94, 0x3a, 0xc0, 0x30, 0x95
};

// Tile G_tiles_30: 16x16 pixels, 8x16 bytes.
const u8 G_tiles_30[8 * 16] = {
	0xc0, 0xc0, 0xca, 0xc4, 0xc0, 0xc0, 0x84, 0xc0,
	0x84, 0xc0, 0xca, 0xc4, 0xc0, 0xc4, 0x84, 0xc0,
	0x84, 0xc4, 0xca, 0xc4, 0xc0, 0xc4, 0x84, 0x48,
	0x84, 0xc4, 0xca, 0xc4, 0xc0, 0xc4, 0xc0, 0x48,
	0x48, 0x4c, 0xca, 0xcc, 0xc0, 0xc4, 0x84, 0x84,
	0x84, 0xcc, 0xca, 0xcc, 0xca, 0x4c, 0xc0, 0x48,
	0x48, 0xc4, 0xf4, 0xcc, 0xca, 0xc4, 0x8e, 0xf0,
	0x84, 0xc8, 0xed, 0xc4, 0xca, 0x4d, 0x8e, 0xf8,
	0xac, 0x4c, 0x84, 0xcc, 0x8e, 0xc4, 0xf8, 0xf0,
	0xd4, 0x5c, 0xda, 0xc5, 0x8e, 0x4d, 0xc0, 0xe0,
	0xf0, 0xd0, 0xc0, 0xc8, 0xda, 0xbc, 0xda, 0x68,
	0x94, 0xd0, 0xd4, 0xc5, 0xf4, 0xe0, 0x68, 0xf0,
	0x3c, 0xe0, 0xf0, 0xd4, 0x94, 0xf0, 0xd0, 0xd0,
	0xf2, 0x68, 0xb4, 0xd0, 0xe0, 0xe0, 0xe0, 0xf1,
	0x72, 0xf2, 0x79, 0x79, 0xf0, 0xb6, 0xf2, 0xb3,
	0x31, 0xb1, 0x33, 0xb1, 0xb1, 0x31, 0x33, 0x32
};