//-----------------------------LICENSE NOTICE------------------------------------
//  This file is part of Jarlac
//  Copyright (C) 2018 Retrobytes Productions
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//------------------------------------------------------------------------------

#include "draw.h"

void drawRoom(){

	u8 x;

	Heart *heart = heartsList;
	Entity *myHero = &hero;

	enteringPosition.xPos = hero.xPos;
	enteringPosition.yPos = hero.yPos;
	enteringPosition.xSpeed = hero.xSpeed;
	enteringPosition.ySpeed = hero.ySpeed;
	enteringPosition.state = hero.state;

	decompress(G_levelMaps[room], G_currentMap);

	initArray(globalLavas, MAX_LAVAS);
	initArray(globalEnemies, MAX_ENEMIES);


	for(x=0;x<MAX_HEARTS && heart->room <= room;x++){

		if(heart->room == room){

			if(heart->state == HEART_STATE_STONE){

				addEntity(ENEMY_TYPE_CORAZON_PIEDRA, heart->x * 8 + 4 - CORAZON_W/2, heart->y * 16 + 16 - CORAZON_H + 2, FALSE, globalEnemies);

			} 
			else if(heart->state == HEART_STATE_NORMAL){

				addEntity(ENEMY_TYPE_CORAZON, heart->x * 8 + 4 - CORAZON_W/2, heart->y * 16 + 16 - CORAZON_H + 2, FALSE, globalEnemies);
			}

			break;
		}

		heart++;

	}


	if(room == 14){

		addEntity(end ? ENEMY_TYPE_CHOCHONA_FREE : ENEMY_TYPE_CHOCHONA, 8 * 4, 16 * 6 - CHOCHONA_H + 2, FALSE, globalEnemies);

		if(hearts == MAX_HEARTS && topo && !end){

			if(myHero->facingLeft){


				addEntity(ENEMY_TYPE_MAGO, 9, 16 * 6 - MAGO_H + 2, FALSE, globalEnemies);
				addEntity(ENEMY_TYPE_BRAZO, 9 + MAGO_W, 16 * 6 - MAGO_H + 6, FALSE, globalEnemies);

			}
			else{

				addEntity(ENEMY_TYPE_MAGO, 7 * 9, 16 * 6 - MAGO_H + 2, TRUE, globalEnemies);
				addEntity(ENEMY_TYPE_BRAZO, 7 * 9 - BRAZO_W, 16 * 6 - MAGO_H + 6, TRUE, globalEnemies);
			}

		}

	}
	

	drawTileBox8x16(0, 0, 10, 8, SCR_BUFF, TRUE);
	drawTileBox8x16(0, 0, 10, 8, SCR_VMEM, FALSE);

	//drawNumber(room, 2, 0, 128);

}

void drawEntity(Entity* entity){

	u8* sprite;
	u8 facingLeft;
	
	if(entity->type == ENEMY_TYPE_PLATFORM) facingLeft = FALSE; //Las plataformas no las pintamos volteadas
	else facingLeft = entity->facingLeft;

	animate(entity);

	sprite = entity->animation.frames[entity->animation.frame]->sprite;
	
	if(sprite == G_jarlac_ataca2){

		drawClippedSprite(G_destello_jarlac, entity->xPos + (facingLeft ? -DESTELLO_W : HERO_W), entity->yPos, DESTELLO_W, DESTELLO_H, facingLeft);

	}
	

	drawClippedSprite(sprite, entity->xPos, entity->yPos, entity->width, entity->height, facingLeft);

}

void deleteEntity(Entity* entity){

	u8* sprite;
	static u8* psprite; 

	if(entity->type != ENEMY_TYPE_CORAZON_PIEDRA){

		eraseClippedSprite(entity->pxPos, entity->pyPos, entity->pwidth, entity->pheight);

	}
	
	if(entity == &hero){

		sprite = entity->animation.frames[entity->animation.frame]->sprite;

		if(psprite == G_jarlac_ataca2){
		
			//Borrado destello
			eraseClippedSprite(entity->pxPos + HERO_W, entity->pyPos , DESTELLO_W, DESTELLO_H);
			eraseClippedSprite(entity->pxPos - DESTELLO_W - 1, entity->pyPos , DESTELLO_W, DESTELLO_H);

		}

		psprite = sprite;		

	}

}

void drawEnemies(Entity *enemy, u8 draw, u8 max){

	//u8 max = MAX_ENEMIES;

    while(max){

    	if(draw){

    		if(enemy->state > ENEMY_STATE_INACTIVE) drawEntity(enemy);

    	}
    	else if(enemy->pstate != ENEMY_STATE_INACTIVE){

    		if(enemy->type != ENEMY_TYPE_CHOCHONA){

    			deleteEntity(enemy);
    			
    		}
    		
    	 }

    	enemy++; max--;

    }

}
void updateEnergy(){

	u8 x;

	u8* pvideo = cpctm_screenPtr(SCR_VMEM, 4, 164);
	cpct_drawSolidBox(pvideo, 240, 15, 3);

	for(x=0;x<energy/4;x++){

		cpct_drawSprite(G_energy, pvideo++, 1, 3);

	}

}

void updateMagic(){

	u8 x;

	u8* pvideo = cpctm_screenPtr(SCR_VMEM, 61, 164);
	cpct_drawSolidBox(pvideo, 240, 15, 3);

	for(x=0;x<magic/4;x++){

		cpct_drawSprite(G_magic, pvideo++, 1, 3);

	}

}

void updateLives(){

	drawNumber(lives, 1, 10, 173);

}

void updateScore(){

	if(score > MAX_SCORE) score = MAX_SCORE;

	drawNumber(score, 6, 31, 140);

}


void updateHearts(){

	u8 x;

	u8* pvideo = cpctm_screenPtr(SCR_VMEM, 62, 174);

	for(x=0;x < 6 && x < hearts;x++){

		cpct_drawSprite(G_coron, pvideo+=2, 1, 2);

	}

	while(x++ < 6){

		cpct_drawSprite(G_coroff, pvideo+=2, 1, 2);

	}

	pvideo = cpctm_screenPtr(SCR_VMEM, 61, 177);

	for(x=6;x < MAX_HEARTS && x < hearts;x++){

		cpct_drawSprite(G_coron, pvideo+=2, 1, 2);

	}

	while(x++ < MAX_HEARTS){

		cpct_drawSprite(G_coroff, pvideo+=2, 1, 2);

	}


}

void drawSelector(u8 color, u8 xPos, u8 yPos){

    u8* pvideo = cpct_getScreenPtr(SCR_VMEM, xPos, yPos + 3);

    cpct_drawSolidBox(pvideo, color, 1, 2);

}


void clearGameScreen(u8* buffer){

	u8* pvideo = cpct_getScreenPtr(buffer, MIN_X, MIN_Y);
	cpct_drawSolidBox(pvideo, 192, 64, MAX_Y - MIN_Y + 1);

	pvideo = cpct_getScreenPtr(buffer, MIN_X + 64, MIN_Y);
	cpct_drawSolidBox(pvideo, 192, 16, MAX_Y - MIN_Y + 1);

}
