//-----------------------------LICENSE NOTICE------------------------------------
//  This file is part of Jarlac
//  Copyright (C) 2018 Retrobytes Productions
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//------------------------------------------------------------------------------


#include "video.h"

const u8 G_graphics_palette[16] = { 0x16, 0x14, 0x00, 0x0B, 0x03, 0x1C, 0x0E, 0x0C, 0x04, 0x15, 0x17, 0x1B, 0x16, 0x1A, 0x18, 0x0D};
const u8 G_black_palette[16] 	= { 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14};

u8* const g_scrbuffers[2] = {SCR_VMEM, SCR_BUFF};

// Create a 256-byte aligned transparent mask table, for mode 0,
// using palette colour index 0 as transparent
cpctm_createPixelFlippingTable(g_flipTable, 0x0A00, M0);
cpctm_createTransparentMaskTable(g_transparencyMaskTable, 0x0B00, M0, 0);

void drawClippedSprite(u8* sprite, i16 xPos, i16 yPos, u8 width, u8 height, u8 facingLeft){

    u8 h = height;
    u8 start = 0;

    if(yPos > MAX_Y || yPos + height < MIN_Y) height = 0;
    else if(yPos + height > MAX_Y){

    	height = MAX_Y - yPos + 1;

    }
    else if(yPos < MIN_Y){

    	height = yPos + height - MIN_Y;
     	start = MIN_Y - yPos; //h - height;
    	yPos = MIN_Y;

    }

    if(height){

		//In this case we don't have to clip
		if(xPos >= MIN_X && xPos + width <= MAX_X + 1){

			if(facingLeft) cpct_drawSpriteHFlipMasked_at(sprite + (start * width), cpct_getScreenPtr(g_scrbuffers[1], xPos, yPos), width, height, g_flipTable);
			else cpct_drawSpriteMaskedAlignedTable(sprite + (start * width), cpct_getScreenPtr(g_scrbuffers[1], xPos, yPos), width, height, g_transparencyMaskTable);

		}
		else if(xPos <= MAX_X && xPos + width > MAX_X + 1){ //Right clip

			while(height){

        if(facingLeft) cpct_drawSpriteHFlipMasked_at(sprite + (width - (MAX_X - xPos + 1)) + ((height - 1 + start) * width), cpct_getScreenPtr(g_scrbuffers[1], xPos, yPos + height - 1), MAX_X - xPos + 1, 1, g_flipTable);
        else cpct_drawSpriteMaskedAlignedTable(sprite + ((height - 1 + start) * width), cpct_getScreenPtr(g_scrbuffers[1], xPos, yPos + height - 1), MAX_X - xPos + 1, 1, g_transparencyMaskTable);

				height--;

			}

		}
		else if(xPos < MIN_X && xPos + width > MIN_X){ //Left clip

			while(height) {

				if(facingLeft) cpct_drawSpriteHFlipMasked_at(sprite + (MIN_X) + ((height - 1 + start) * width), cpct_getScreenPtr(g_scrbuffers[1], MIN_X, yPos + height - 1), width - (MIN_X - xPos), 1, g_flipTable);
				else cpct_drawSpriteMaskedAlignedTable(sprite + (MIN_X - xPos) + ((height - 1 + start) * width), cpct_getScreenPtr(g_scrbuffers[1], MIN_X, yPos + height - 1), width - (MIN_X - xPos), 1, g_transparencyMaskTable);

				height--;

			}

		}

    }

}

void eraseClippedSprite(i16 xPos, i16 yPos, u8 width, u8 height){

	u8 tWidth = width / 8, tHeight = height / 16;

	if(!tWidth) tWidth = 1; //Anchos < 8

	tHeight += height % 16  ? 1 : 0;

	//Revisar si esto sigue siendo necesario

	if(xPos < MIN_X) xPos = MIN_X;
	else if(xPos > MAX_X) xPos = MAX_X;
	if(yPos < MIN_Y) yPos = MIN_Y;
	else if(yPos > MAX_Y) yPos = MAX_Y;

	tWidth  += (xPos + width)  % 16  ? 1 : 0;
	tHeight += (yPos + height) % 16  ? 1 : 0;

	drawTileBox8x16(xPos / 8, yPos / 16, tWidth, tHeight, g_scrbuffers[1], FALSE);

}

void forceFrontBuffer(u8** scrbuffers){

	scrbuffers[0] = SCR_BUFF;
	scrbuffers[1] = SCR_VMEM;

	screenAddress = SCR_VMEM_ADDRESS;

}

void swapBuffers(u8** scrbuffers) {

    u8* aux; // Auxiliary pointer for making the change

    aux = scrbuffers[0];
    scrbuffers[0] = scrbuffers[1];
    scrbuffers[1] = aux;

    if(aux == SCR_VMEM) screenAddress = SCR_BUFF_ADDRESS;
    else screenAddress = SCR_VMEM_ADDRESS;

    if(earthQuake && screenAddress == SCR_VMEM_ADDRESS){

      screenAddress -= 40;
      earthQuake--;

    }

}
